@@ -1,4 +1,5 @@
 import codecs
+import functools
 import io
 import logging
 import os
@@ -52,7 +53,7 @@ from threading import Thread
 
 __author__ = """Markus Gerstel"""
 __email__ = "scientificsoftware@diamond.ac.uk"
-__version__ = "2.1.0"
+__version__ = "2.3.0"
 
 logger = logging.getLogger("procrunner")
 logger.addHandler(logging.NullHandler())
@@ -131,6 +132,7 @@ class _NonBlockingStreamReader:
                 else:
                     if self._closing:
                         break
+            self._stream.close()
             self._terminated = True
             la.flush()
             if self._debug:
@@ -150,6 +152,7 @@ class _NonBlockingStreamReader:
                             print(linedecode)
                         if callback:
                             callback(linedecode)
+            self._stream.close()
             self._terminated = True
             if self._debug:
                 logger.debug("Stream reader terminated")
@@ -209,7 +212,6 @@ class _NonBlockingStreamWriter:
         self._buffer = data
         self._buffer_len = len(data)
         self._buffer_pos = 0
-        self._debug = debug
         self._max_block_len = 4096
         self._stream = stream
         self._terminated = False
@@ -273,7 +275,7 @@ def _path_resolve(obj):
     return obj
 
 
-def _windows_resolve(command):
+def _windows_resolve(command, path=None):
     """
     Try and find the full path and file extension of the executable to run.
     This is so that e.g. calls to 'somescript' will point at 'somescript.cmd'
@@ -288,7 +290,7 @@ def _windows_resolve(command):
     if not command or not isinstance(command[0], str):
         return command
 
-    found_executable = shutil.which(command[0])
+    found_executable = shutil.which(command[0], path=path)
     if found_executable:
         logger.debug("Resolved %s as %s", command[0], found_executable)
         return (found_executable, *command[1:])
@@ -297,7 +299,7 @@ def _windows_resolve(command):
         # Special case. shutil.which may not detect file extensions if a full
         # path is given, so try to resolve the executable explicitly
         for extension in os.getenv("PATHEXT").split(os.pathsep):
-            found_executable = shutil.which(command[0] + extension)
+            found_executable = shutil.which(command[0] + extension, path=path)
             if found_executable:
                 return (found_executable, *command[1:])
 
@@ -333,7 +335,7 @@ class ReturnObject(subprocess.CompletedProcess):
         if key in self._extras:
             return self._extras[key]
         if not hasattr(self, key):
-            raise KeyError("Unknown attribute {key}".format(key=key))
+            raise KeyError(f"Unknown attribute {key}")
         return getattr(self, key)
 
     def __eq__(self, other):
@@ -413,10 +415,26 @@ class ReturnObject(subprocess.CompletedProcess):
         self._extras.update(dictionary)
 
 
+def _deprecate_argument_calling(f):
+    @functools.wraps(f)
+    def wrapper(*args, **kwargs):
+        if len(args) > 1:
+            warnings.warn(
+                "Calling procrunner.run() with unnamed arguments (apart from "
+                "the command) is deprecated. Use keyword arguments instead.",
+                DeprecationWarning,
+                stacklevel=2,
+            )
+        return f(*args, **kwargs)
+
+    return wrapper
+
+
+@_deprecate_argument_calling
 def run(
     command,
     timeout=None,
-    debug=False,
+    debug=None,
     stdin=None,
     print_stdout=True,
     print_stderr=True,
@@ -436,7 +454,7 @@ def run(
 
     :param array command: Command line to be run, specified as array.
     :param timeout: Terminate program execution after this many seconds.
-    :param boolean debug: Enable further debug messages.
+    :param boolean debug: Enable further debug messages. (deprecated)
     :param stdin: Optional bytestring that is passed to command stdin.
     :param boolean print_stdout: Pass stdout through to sys.stdout.
     :param boolean print_stderr: Pass stderr through to sys.stderr.
@@ -470,6 +488,10 @@ def run(
     else:
         assert sys.platform != "win32", "stdin argument not supported on Windows"
         stdin_pipe = subprocess.PIPE
+    if debug is not None:
+        warnings.warn(
+            "Use of the debug parameter is deprecated", DeprecationWarning, stacklevel=3
+        )
 
     start_time = timeit.default_timer()
     if timeout is not None:
@@ -478,7 +500,7 @@ def run(
             warnings.warn(
                 "Using procrunner with timeout and without raise_timeout_exception set is deprecated",
                 DeprecationWarning,
-                stacklevel=2,
+                stacklevel=3,
             )
 
     if environment is not None:
@@ -496,11 +518,13 @@ def run(
     command = tuple(_path_resolve(part) for part in command)
     if win32resolve and sys.platform == "win32":
         command = _windows_resolve(command)
+    if working_directory and sys.version_info < (3, 7):
+        working_directory = os.fspath(working_directory)
 
     p = subprocess.Popen(
         command,
         shell=False,
-        cwd=_path_resolve(working_directory),
+        cwd=working_directory,
         env=env,
         stdin=stdin_pipe,
         stdout=subprocess.PIPE,
