@@ -1,6 +1,7 @@
 import copy
-import mock
+from unittest import mock
 import os
+import pathlib
 import procrunner
 import pytest
 import sys
@@ -21,7 +22,7 @@ def test_run_command_aborts_after_timeout_legacy(
 
     with pytest.raises(RuntimeError):
         with pytest.warns(DeprecationWarning, match="timeout"):
-            procrunner.run(task, -1, False)
+            procrunner.run(task, timeout=-1, debug=False)
 
     assert mock_subprocess.Popen.called
     assert mock_process.terminate.called
@@ -42,7 +43,7 @@ def test_run_command_aborts_after_timeout(
     task = ["___"]
 
     with pytest.raises(RuntimeError):
-        procrunner.run(task, -1, False, raise_timeout_exception=True)
+        procrunner.run(task, timeout=-1, raise_timeout_exception=True)
 
     assert mock_subprocess.Popen.called
     assert mock_process.terminate.called
@@ -83,30 +84,32 @@ def test_run_command_runs_command_and_directs_pipelines(
 
     actual = procrunner.run(
         command,
-        0.5,
-        False,
+        timeout=0.5,
         callback_stdout=mock.sentinel.callback_stdout,
         callback_stderr=mock.sentinel.callback_stderr,
-        working_directory=mock.sentinel.cwd,
+        working_directory=pathlib.Path("somecwd"),
         raise_timeout_exception=True,
     )
 
     assert mock_subprocess.Popen.called
     assert mock_subprocess.Popen.call_args[1]["env"] == os.environ
-    assert mock_subprocess.Popen.call_args[1]["cwd"] == mock.sentinel.cwd
+    assert mock_subprocess.Popen.call_args[1]["cwd"] in (
+        pathlib.Path("somecwd"),
+        "somecwd",
+    )
     mock_streamreader.assert_has_calls(
         [
             mock.call(
                 stream_stdout,
                 output=mock.ANY,
-                debug=mock.ANY,
+                debug=None,
                 notify=mock.ANY,
                 callback=mock.sentinel.callback_stdout,
             ),
             mock.call(
                 stream_stderr,
                 output=mock.ANY,
-                debug=mock.ANY,
+                debug=None,
                 notify=mock.ANY,
                 callback=mock.sentinel.callback_stderr,
             ),
@@ -128,10 +131,21 @@ def test_run_command_runs_command_and_directs_pipelines(
 def test_default_process_environment_is_parent_environment(mock_subprocess):
     mock_subprocess.Popen.side_effect = NotImplementedError()  # cut calls short
     with pytest.raises(NotImplementedError):
-        procrunner.run([mock.Mock()], -1, False, raise_timeout_exception=True)
+        procrunner.run([mock.Mock()], timeout=-1, raise_timeout_exception=True)
     assert mock_subprocess.Popen.call_args[1]["env"] == os.environ
 
 
+@mock.patch("procrunner.subprocess")
+def test_using_debug_parameter_raises_warning(mock_subprocess):
+    mock_subprocess.Popen.side_effect = NotImplementedError()  # cut calls short
+    with pytest.warns(DeprecationWarning, match="debug"):
+        with pytest.raises(NotImplementedError):
+            procrunner.run([mock.Mock()], debug=True)
+    with pytest.warns(DeprecationWarning, match="debug"):
+        with pytest.raises(NotImplementedError):
+            procrunner.run([mock.Mock()], debug=False)
+
+
 @mock.patch("procrunner.subprocess")
 def test_pass_custom_environment_to_process(mock_subprocess):
     mock_subprocess.Popen.side_effect = NotImplementedError()  # cut calls short
@@ -140,8 +154,7 @@ def test_pass_custom_environment_to_process(mock_subprocess):
     with pytest.raises(NotImplementedError):
         procrunner.run(
             [mock.Mock()],
-            -1,
-            False,
+            timeout=-1,
             environment=copy.copy(mock_env),
             raise_timeout_exception=True,
         )
@@ -157,8 +170,7 @@ def test_pass_custom_environment_to_process_and_add_another_value(mock_subproces
     with pytest.raises(NotImplementedError):
         procrunner.run(
             [mock.Mock()],
-            -1,
-            False,
+            timeout=-1,
             environment=copy.copy(mock_env1),
             environment_override=copy.copy(mock_env2),
             raise_timeout_exception=True,
@@ -175,8 +187,7 @@ def test_use_default_process_environment_and_add_another_value(mock_subprocess):
     with pytest.raises(NotImplementedError):
         procrunner.run(
             [mock.Mock()],
-            -1,
-            False,
+            timeout=-1,
             environment_override=copy.copy(mock_env2),
             raise_timeout_exception=True,
         )
@@ -204,8 +215,7 @@ def test_use_default_process_environment_and_override_a_value(mock_subprocess):
     with pytest.raises(NotImplementedError):
         procrunner.run(
             [mock.Mock()],
-            -1,
-            False,
+            timeout=-1,
             environment_override={
                 random_environment_variable: "X" + random_environment_value
             },
