@@ -40,11 +40,10 @@ def test_decode_invalid_utf8_input(capsys):
     assert err == ""
 
 
-def test_running_wget(tmpdir):
-    tmpdir.chdir()
+def test_running_wget(tmp_path):
     command = ["wget", "https://www.google.com", "-O", "-"]
     try:
-        result = procrunner.run(command)
+        result = procrunner.run(command, working_directory=tmp_path)
     except OSError as e:
         if e.errno == 2:
             pytest.skip("wget not available")
@@ -54,15 +53,17 @@ def test_running_wget(tmpdir):
     assert b"google" in result.stdout
 
 
-def test_path_object_resolution(tmpdir):
+def test_path_object_resolution(tmp_path):
     sentinel_value = b"sentinel"
-    tmpdir.join("tempfile").write(sentinel_value)
-    tmpdir.join("reader.py").write("print(open('tempfile').read())")
+    tmp_path.joinpath("tempfile").write_bytes(sentinel_value)
+    tmp_path.joinpath("reader.py").write_text(
+        "with open('tempfile') as fh:\n    print(fh.read())"
+    )
     assert "LEAK_DETECTOR" not in os.environ
     result = procrunner.run(
-        [sys.executable, tmpdir.join("reader.py")],
+        [sys.executable, tmp_path / "reader.py"],
         environment_override={"PYTHONHASHSEED": "random", "LEAK_DETECTOR": "1"},
-        working_directory=tmpdir,
+        working_directory=tmp_path,
     )
     assert result.returncode == 0
     assert not result.stderr
@@ -118,3 +119,14 @@ def test_timeout_behaviour(tmp_path):
     assert te.value.stderr == b""
     assert te.value.timeout == 0.1
     assert te.value.cmd == command
+
+
+def test_argument_deprecation(tmp_path):
+    with pytest.warns(DeprecationWarning, match="keyword arguments"):
+        result = procrunner.run(
+            [sys.executable, "-V"],
+            None,
+            working_directory=tmp_path,
+        )
+    assert not result.returncode
+    assert result.stderr or result.stdout
